@@ -167,7 +167,7 @@ func stubInstance(imageID, instanceID string) *ec2.Instance {
 		ImageId:    aws.String(imageID),
 		InstanceId: aws.String(instanceID),
 		State: &ec2.InstanceState{
-			Name: aws.String("Running"),
+			Name: aws.String(ec2.InstanceStateNameRunning),
 			Code: aws.Int64(16),
 		},
 		LaunchTime:       aws.Time(time.Now()),
@@ -248,7 +248,7 @@ func stubReservation(imageID, instanceID string) *ec2.Reservation {
 				ImageId:    aws.String(imageID),
 				InstanceId: aws.String(instanceID),
 				State: &ec2.InstanceState{
-					Name: aws.String("Running"),
+					Name: aws.String(ec2.InstanceStateNameRunning),
 					Code: aws.Int64(16),
 				},
 				LaunchTime: aws.Time(time.Now()),
@@ -260,7 +260,7 @@ func stubReservation(imageID, instanceID string) *ec2.Reservation {
 	}
 }
 
-func stubDescribeInstancesOutput(imageID, instanceID string) *ec2.DescribeInstancesOutput {
+func stubDescribeInstancesOutput(imageID, instanceID string, state string) *ec2.DescribeInstancesOutput {
 	return &ec2.DescribeInstancesOutput{
 		Reservations: []*ec2.Reservation{
 			{
@@ -269,7 +269,7 @@ func stubDescribeInstancesOutput(imageID, instanceID string) *ec2.DescribeInstan
 						ImageId:    aws.String(imageID),
 						InstanceId: aws.String(instanceID),
 						State: &ec2.InstanceState{
-							Name: aws.String("Running"),
+							Name: aws.String(state),
 							Code: aws.Int64(16),
 						},
 						LaunchTime: aws.Time(time.Now()),
